@@ -6,7 +6,8 @@ the necessary components and configurations. Any global settings for the package
 """
 
 from githubapp.config import Config
+from githubapp.event_check_run import EventCheckRun
 
-__version__ = "0.24.4"
+__version__ = "0.27.2"
 
-__all__ = ["Config"]
+__all__ = ["Config", "EventCheckRun"]
